@@ -7,6 +7,14 @@ from shared_dependencies.sentry import safe_capture_exception
 from shared_dependencies.http_client import CustomAsyncClient
 
 
+def get_message_from_exception(e):
+    """
+    Use to avoid nested FastAPI responses when a microservices calls another one and gets an exception
+    """
+    if not hasattr(e, "detail"):
+        return str(e)
+    return e.detail if "message" not in e.detail else e.detail["message"]
+
 
 @contextlib.asynccontextmanager
 async def patient_httpx_client(*args, **kwargs):
